using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.ExtendedControls;
using CMS.FormControls;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.SiteProvider;
using CMS.TreeEngine;
using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.PortalEngine;
using CMS.UIControls;
using CMS.LicenseProvider;

using TreeNode = CMS.TreeEngine.TreeNode;

public partial class CMSDesk_Content_Properties_general : CMSDeskPage
{
    #region "Private variables"

    protected string mForums = null;
    protected string mMessageBoards = null;
    protected string mEditableContent = null;
    protected int nodeId = 0;
    protected string mSave = null;
    protected string imagesUrl = null;
    protected bool canEditOwner = false;
    protected bool canEdit = true;
    protected TreeNode node = null;

    bool hasAdHocBoard = false;
    bool hasAdHocForum = false;
    FormEngineUserControl usrOwner = null;

    #endregion


    #region "Page events"

    protected void Page_Load(object sender, EventArgs e)
    {
        // Register the scripts
        ScriptHelper.RegisterProgress(this.Page);

        usrOwner = this.Page.LoadControl("~/CMSFormControls/selectuser.ascx") as FormEngineUserControl;
        usrOwner.ID = "ctrlUsrOwner";
        plcUsrOwner.Controls.Add(usrOwner);

        UIContext.PropertyTab = PropertyTabEnum.General;

        imagesUrl = ResolveUrl(UrlHelper.ImagesDirectory + "/CMSDesk/Content/");

        nodeId = QueryHelper.GetInteger("nodeid", 0);

        // Init strings
        pnlCache.GroupingText = ResHelper.GetString("GeneralProperties.CacheGroup");
        pnlOther.GroupingText = ResHelper.GetString("GeneralProperties.OtherGroup");
        pnlAdvanced.GroupingText = ResHelper.GetString("GeneralProperties.AdvancedGroup");

        // Advanced section
        mEditableContent = ResHelper.GetString("GeneralProperties.EditableContent");
        mForums = ResHelper.GetString("PageProperties.Forums");
        mMessageBoards = ResHelper.GetString("PageProperties.MessageBoards");
        lnkEditableContent.OnClientClick = "ShowEditableContent(); return false;";
        lnkMessageBoards.OnClientClick = "ShowMessageBoards(); return false;";
        lnkForums.OnClientClick = "ShowForums(); return false;";
        imgEditableContent.ImageUrl = UrlHelper.ImagesDirectory + "/CMSDesk/Content/Properties/EditableContent/editablecontent.gif";
        imgMessageBoards.ImageUrl = UrlHelper.ImagesDirectory + "/CMSModules/MessageBoards/Tools/messageboard.gif";
        imgForums.ImageUrl = UrlHelper.ImagesDirectory + "/CMSModules/Forums/Tools/Forums/forum.gif";

        radInherit.Text = ResHelper.GetString("GeneralProperties.radInherit");
        radYes.Text = ResHelper.GetString("general.yes");
        radNo.Text = ResHelper.GetString("general.no");

        lblCacheMinutes.Text = ResHelper.GetString("GeneralProperties.cacheMinutes");

        lblNameTitle.Text = ResHelper.GetString("GeneralProperties.Name");
        lblNamePathTitle.Text = ResHelper.GetString("GeneralProperties.NamePath");
        lblAliasPathTitle.Text = ResHelper.GetString("GeneralProperties.AliasPath");
        lblTypeTitle.Text = ResHelper.GetString("GeneralProperties.Type");
        lblNodeIDTitle.Text = ResHelper.GetString("GeneralProperties.NodeID");
        lblLastModifiedByTitle.Text = ResHelper.GetString("GeneralProperties.LastModifiedBy");
        lblLastModifiedTitle.Text = ResHelper.GetString("GeneralProperties.LastModified");
        lblLiveURLTitle.Text = ResHelper.GetString("GeneralProperties.LiveURL");
        lblGUIDTitle.Text = ResHelper.GetString("GeneralProperties.GUID");
        lblCultureTitle.Text = ResHelper.GetString("GeneralProperties.Culture");
        lblCreatedByTitle.Text = ResHelper.GetString("GeneralProperties.CreatedBy");
        lblCreatedTitle.Text = ResHelper.GetString("GeneralProperties.Created");
        lblOwnerTitle.Text = ResHelper.GetString("GeneralProperties.Owner");
        lblCssStyle.Text = ResHelper.GetString("PageProperties.CssStyle");
        lblPublishedTitle.Text = ResHelper.GetString("PageProperties.Published");

        chkCssStyle.Text = ResHelper.GetString("Metadata.Inherit");

        if (CMSContext.CurrentSite != null)
        {
            usrOwner.SetValue("SiteID", CMSContext.CurrentSite.SiteID);
        }

        imgSave.ImageUrl = imagesUrl + "save.gif";
        mSave = ResHelper.GetString("general.save");

        int documentId = 0;

        // Get the document
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        node = tree.SelectSingleNode(nodeId, CMSContext.PreferredCultureCode);
        if (node != null)
        {
            documentId = node.DocumentID;
            canEditOwner = (CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Content", "ModifyPermissions") && (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.ModifyPermissions) != AuthorizationResultEnum.Denied)) || (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.ModifyPermissions) == AuthorizationResultEnum.Allowed);

            ReloadData();
        }

        // Generate executive script
        string script = "function ShowEditableContent() { modalDialog('" + ResolveUrl("Advanced/EditableContent/default.aspx") + "?nodeid=" + nodeId + "', 'EditableContent', 1000, 700); } \n";

        if (hasAdHocBoard)
        {
            plcAdHocBoards.Visible = true;
            script += "function ShowMessageBoards() { modalDialog('" + ResolveUrl("~/CMSModules/MessageBoards/Content/Properties/default.aspx") + "?documentid=" + documentId + "', 'MessageBoards', 1000, 680); } \n";
        }

        if (hasAdHocForum)
        {
            plcAdHocForums.Visible = true;
            script += "function ShowForums() { modalDialog('" + ResolveUrl("~/CMSModules/Forums/Content/Properties/default.aspx") + "?documentid=" + documentId + "', 'Forums', 1000, 680); } \n";
        }

        Page.ClientScript.RegisterClientScriptBlock(typeof(string), "ModalDialogsToAdvancedSection", ScriptHelper.GetScript(script));
    }


    protected override void OnPreRender(EventArgs e)
    {
        base.OnPreRender(e);

        if (canEdit)
        {
            // Shortcuts script
            Page.ClientScript.RegisterClientScriptBlock(typeof(string), "EditShortcuts",
                    "<script type=\"text/javascript\" src=\"" + ResolveUrl("~/CMSScripts/shortcuts.js") + "\"></script>" +
                    ScriptHelper.GetScript("function SaveDocument() { " + ClientScript.GetPostBackEventReference(lnkSave, null) + " } \n"
                ));
        }
    }

    #endregion


    #region "Private methods"

    private void ReloadData()
    {
        //node = tree.SelectSingleNode(nodeId);
        if (node != null)
        {
            // Check read permissions
            if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Read) == AuthorizationResultEnum.Denied)
            {
                RedirectToAccessDenied(String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoreaddocument"), node.NodeAliasPath));
            }
            else
            {
                // Check modify permissions
                if (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(node, NodePermissionsEnum.Modify) == AuthorizationResultEnum.Denied)
                {
                    // disable form editing                                                            
                    DisableFormEditing();

                    // show access denied message
                    lblInfo.Text = String.Format(ResHelper.GetString("cmsdesk.notauthorizedtoeditdocument"), node.NodeAliasPath);
                }

                // Show document group owner selector

                if (ModuleEntry.IsModuleLoaded(ModuleEntry.COMMUNITY) && canEditOwner && (LicenseHelper.CurrentEdition == ProductEditionEnum.Community))
                {
                    plcOwnerGroup.Controls.Clear();
                    // Initialize table
                    TableRow rowOwner = new TableRow();
                    TableCell cellTitle = new TableCell();
                    TableCell cellSelector = new TableCell();

                    // Initialize caption
                    LocalizedLabel lblOwnerGroup = new LocalizedLabel();
                    lblOwnerGroup.EnableViewState = false;
                    lblOwnerGroup.ResourceString = "community.group.documentowner";
                    lblOwnerGroup.ID = "lblOwnerGroup";
                    cellTitle.Controls.Add(lblOwnerGroup);

                    // Initialize selector
                    FormEngineUserControl fcDocumentGroupSelector = (FormEngineUserControl)Page.LoadControl("~/CMSAdminControls/UI/DocumentGroupSelector.ascx");
                    fcDocumentGroupSelector.ID = "fcDocumentGroupSelector";
                    cellSelector.Controls.Add(fcDocumentGroupSelector);
                    fcDocumentGroupSelector.Value = ValidationHelper.GetInteger(node.GetValue("NodeGroupID"), 0);
                    fcDocumentGroupSelector.SetValue("siteid", CMSContext.CurrentSiteID);
                    fcDocumentGroupSelector.SetValue("nodeid", nodeId);

                    // Add controls to containers
                    rowOwner.Cells.Add(cellTitle);
                    rowOwner.Cells.Add(cellSelector);
                    plcOwnerGroup.Controls.Add(rowOwner);
                    plcOwnerGroup.Visible = true;
                }

                // Show owner editing only when authorized to change the permissions
                if (canEditOwner)
                {
                    lblOwner.Visible = false;
                    usrOwner.Visible = true;
                }

                if (!RequestHelper.IsPostBack())
                {
                    if (canEditOwner)
                    {
                        usrOwner.Value = node.GetValue("NodeOwner");
                    }
                }

                // Load the data
                lblName.Text = HttpUtility.HtmlEncode(node.DocumentName);
                lblNamePath.Text = HttpUtility.HtmlEncode(Convert.ToString(node.GetValue("DocumentNamePath")));
                lblAliasPath.Text = Convert.ToString(node.NodeAliasPath);
                lblType.Text = DataClassInfoProvider.GetDataClass(node.NodeClassName).ClassDisplayName;
                lblNodeID.Text = Convert.ToString(node.NodeID);

                // Modifier
                int uid = ValidationHelper.GetInteger(node.GetValue("DocumentModifiedByUserId"), 0);
                if (uid > 0)
                {
                    UserInfo ui = UserInfoProvider.GetUserInfo(uid);
                    if (ui != null)
                    {
                        lblLastModifiedBy.Text = HTMLHelper.HTMLEncode(ui.FullName);
                    }
                }

                lblLastModified.Text = Convert.ToString(node.GetValue("DocumentModifiedWhen"));

                // Owner
                uid = ValidationHelper.GetInteger(node.GetValue("NodeOwner"), 0);
                if (uid > 0)
                {
                    UserInfo ui = UserInfoProvider.GetUserInfo(uid);
                    if (ui != null)
                    {
                        lblOwner.Text = HTMLHelper.HTMLEncode(ui.FullName);
                    }
                }

                // URL
                string liveUrl = node.IsLink ? CMSContext.GetUrl(node.NodeAliasPath, null) : CMSContext.GetUrl(node.NodeAliasPath, node.DocumentUrlPath);

                lnkLiveURL.Text = AbsoluteUrl(liveUrl);
                lnkLiveURL.NavigateUrl = liveUrl;

                lblGUID.Text = Convert.ToString(node.NodeGUID);

                // Culture
                CultureInfo ci = CultureInfoProvider.GetCultureInfo(node.DocumentCulture);
                lblCulture.Text = ((ci != null) ? ci.CultureName : node.DocumentCulture);

                // Created by
                uid = ValidationHelper.GetInteger(node.GetValue("DocumentCreatedByUserId"), 0);
                if (uid > 0)
                {
                    UserInfo ui = UserInfoProvider.GetUserInfo(uid);
                    lblCreatedBy.Text = HTMLHelper.HTMLEncode(ui.FullName);
                }

                lblCreated.Text = Convert.ToString(node.GetValue("DocumentCreatedWhen"));

                lblPublished.Text = (node.IsPublished ? "<span class=\"DocumentPublishedYes\">" + ResHelper.GetString("General.Yes") + "</span>" : "<span class=\"DocumentPublishedNo\">" + ResHelper.GetString("General.No") + "</span>");

                bool isRoot = (node.NodeClassName.ToLower() == "cms.root");
                if (!RequestHelper.IsPostBack())
                {
                    // Init radio buttons
                    if (isRoot)
                    {
                        radInherit.Visible = false;
                        chkCssStyle.Visible = false;
                        switch (node.NodeCacheMinutes)
                        {
                            case -1:
                                radNo.Checked = true;
                                radYes.Checked = false;
                                radInherit.Checked = false;
                                txtCacheMinutes.Text = "";
                                break;

                            case 0:
                                radNo.Checked = true;
                                radYes.Checked = false;
                                radInherit.Checked = false;
                                txtCacheMinutes.Text = "";
                                break;

                            default:
                                radNo.Checked = false;
                                radYes.Checked = true;
                                radInherit.Checked = false;
                                txtCacheMinutes.Text = node.NodeCacheMinutes.ToString();
                                break;
                        }
                    }
                    else
                    {
                        switch (node.NodeCacheMinutes)
                        {
                            case -1:
                                radNo.Checked = false;
                                radYes.Checked = false;
                                radInherit.Checked = true;
                                txtCacheMinutes.Text = "";
                                break;

                            case 0:
                                radNo.Checked = true;
                                radYes.Checked = false;
                                radInherit.Checked = false;
                                txtCacheMinutes.Text = "";
                                break;

                            default:
                                radNo.Checked = false;
                                radYes.Checked = true;
                                radInherit.Checked = false;
                                txtCacheMinutes.Text = node.NodeCacheMinutes.ToString();
                                break;
                        }
                    }

                    if (!radYes.Checked)
                    {
                        txtCacheMinutes.Enabled = false;
                    }
                }

                if (!RequestHelper.IsPostBack())
                {
                    // Fill drop down list
                    DataSet ds = CssStylesheetInfoProvider.GetCssStylesheets(CMSContext.CurrentSiteName, "CMS_CssStylesheet.StylesheetID, StylesheetDisplayName", -1);//GetCssStylesheets(CMSContext.CurrentSiteName);
                    if ((ds != null) && (ds.Tables.Count > 0) && (ds.Tables[0].Rows.Count > 0))
                    {
                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            // Add the item
                            ListItem li = new ListItem();
                            li.Text = dr["StylesheetDisplayName"].ToString();
                            li.Value = dr["StylesheetID"].ToString();
                            drpCssStyle.Items.Add(li);
                        }
                    }

                    if (node.GetValue("DocumentStylesheetID") == null)
                    {
                        drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue("(default)"));
                    }
                    else
                    {
                        if (ValidationHelper.GetInteger(node.GetValue("DocumentStylesheetID"), 0) == -1)
                        {
                            if (!isRoot)
                            {
                                drpCssStyle.Enabled = false;
                                chkCssStyle.Checked = true;
                                string value = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentStylesheetID <> -1", "DocumentStylesheetID", null);

                                if (value == "")
                                {
                                    drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue("(default)"));
                                }
                                else
                                {
                                    try
                                    {
                                        drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue(value));
                                    }
                                    catch
                                    {
                                    }
                                }
                            }
                        }
                        else
                        {
                            drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue(node.GetValue("DocumentStylesheetID").ToString()));
                        }
                    }
                }

                RefreshCntRatingResult();

                double rating = 0.0f;
                if (node.DocumentRatings > 0)
                {
                    rating = node.DocumentRatingValue / node.DocumentRatings;
                }
                ratingControl.MaxRating = 10;
                ratingControl.CurrentRating = rating;
                ratingControl.Visible = true;
                ratingControl.Enabled = false;

                btnResetRating.Text = ResHelper.GetString("general.reset");
                btnResetRating.OnClientClick = "if (!confirm(" + ScriptHelper.GetString(ResHelper.GetString("GeneralProperties.ResetRatingConfirmation")) + ")) return false;";

                object[] param = new object[1];
                param[0] = node.DocumentID;

                // Check ad-hoc forum counts
                hasAdHocForum = (ModuleCommands.ForumsGetDocumentForumsCount(node.DocumentID) > 0);

                // Ad-Hoc message boards check
                hasAdHocBoard = (ModuleCommands.MessageBoardGetDocumentBoardsCount(node.DocumentID) > 0);

                plcAdHocForums.Visible = hasAdHocForum;
                plcAdHocBoards.Visible = hasAdHocBoard;
            }
        }
        else
        {
            btnResetRating.Visible = false;
        }
    }


    protected void lnkSave_Click(object sender, EventArgs e)
    {
        // Get the document
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        node = tree.SelectSingleNode(nodeId, CMSContext.PreferredCultureCode);
        if (node != null)
        {
            bool correct = true;

            // Set owner
            int ownerId = ValidationHelper.GetInteger(usrOwner.Value, 0);
            if (ownerId > 0)
            {
                node.SetValue("NodeOwner", usrOwner.Value);
            }
            else
            {
                node.SetValue("NodeOwner", null);
            }


            node.SetValue("DocumentStylesheetID", -1);
            if (!chkCssStyle.Checked)
            {
                if (drpCssStyle.SelectedItem.Text == "(default)" && drpCssStyle.SelectedItem.Value == Convert.ToString(-1))
                {
                    node.SetValue("DocumentStylesheetID", null);
                }
                else
                {
                    node.SetValue("DocumentStylesheetID", drpCssStyle.SelectedValue);
                }
            }

            // Cache minutes
            int cacheMinutes = 0;
            if (radNo.Checked)
            {
                cacheMinutes = 0;
            }
            else if (radYes.Checked)
            {
                string siteName = CMSContext.CurrentSiteName;

                if (txtCacheMinutes.Text == "")
                {
                    if (radYes.Checked)
                    {
                        correct = false;
                    }
                    else
                    {
                        txtCacheMinutes.Text = SettingsKeyProvider.GetStringValue(siteName + ".CMSCacheMinutes");
                    }
                }
                else
                {
                    int isInteger = ValidationHelper.GetInteger(txtCacheMinutes.Text, -5);
                    if (isInteger <= 0)
                    {
                        correct = false;
                    }
                }

                cacheMinutes = ValidationHelper.GetInteger(txtCacheMinutes.Text, 0);
            }
            else if (radInherit.Checked)
            {
                cacheMinutes = -1;
            }

            // Set cache minutes
            bool clearCache = false;
            if (cacheMinutes != node.NodeCacheMinutes)
            {
                node.NodeCacheMinutes = cacheMinutes;
                clearCache = true;
            }

            if (correct)
            {
                // Save the data
                node.Update();

                // Update search index for node
                if ((node.PublishedVersionExists) && (SearchIndexInfoProvider.SearchEnabled))
                {
                    SearchTaskInfoProvider.CreateTask(SearchTaskTypeEnum.Update, PredefinedObjectType.DOCUMENT, SearchHelper.ID_FIELD, node.GetSearchID());
                }

                // Log synchronization
                DocumentHelper.LogSynchronization(node, CMS.Staging.TaskTypeEnum.UpdateDocument, tree);

                // Clear cache if cache settings changed
                if (clearCache)
                {
                    CacheHelper.ClearCache(null);
                }

                lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                ReloadData();
            }
            else
            {
                lblError.Text = ResHelper.GetString("GeneralProperties.BadCacheMinutes");
            }
        }
    }


    /// <summary>
    /// Disables form editing.
    /// </summary>
    protected void DisableFormEditing()
    {
        canEdit = false;

        pnlDesign.Enabled = false;
        pnlOther.Enabled = false;
        pnlCache.Enabled = false;

        // Disable 'save button'
        lnkSave.Enabled = false;
        lnkSave.CssClass = "MenuItemEditDisabled";
        imgSave.ImageUrl = imagesUrl + "savedisabled.gif";
    }


    protected void radInherit_CheckedChanged(object sender, EventArgs e)
    {
        txtCacheMinutes.Enabled = false;

        if (radYes.Checked)
        {
            txtCacheMinutes.Enabled = true;
        }
    }


    protected void chkCssStyle_CheckedChanged(object sender, EventArgs e)
    {
        if (chkCssStyle.Checked)
        {
            drpCssStyle.Enabled = false;
            string value = PageInfoProvider.GetParentProperty(CMSContext.CurrentSite.SiteID, node.NodeAliasPath, "DocumentStylesheetID <> -1", "DocumentStylesheetID", null);

            if (value == "")
            {
                drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue("(default)"));
            }
            else
            {
                try
                {
                    drpCssStyle.SelectedIndex = drpCssStyle.Items.IndexOf(drpCssStyle.Items.FindByValue(value));
                }
                catch
                {
                }
            }
        }
        else
        {
            drpCssStyle.Enabled = true;
        }
    }


    /// <summary>
    /// Refreshes current rating result. 
    /// </summary>
    protected void RefreshCntRatingResult()
    {
        string msg = null;
        // Avoid division by zero
        if ((node != null) && (node.DocumentRatings > 0))
        {
            msg = String.Format(ResHelper.GetString("GeneralProperties.ContentRatingResult"), (node.DocumentRatingValue * 10) / node.DocumentRatings, node.DocumentRatings);
        }

        if (msg == null)
        {
            msg = ResHelper.GetString("general.na");
        }

        lblContentRatingResult.Text = msg;
    }


    /// <summary>
    /// Resets content rating score.
    /// </summary>
    /// <param name="sender">Sender</param>
    /// <param name="e">Args</param>
    protected void btnResetRating_Click(object sender, EventArgs e)
    {
        if (node != null)
        {
            TreeProvider.ResetRating(node);
            RefreshCntRatingResult();
            ratingControl.CurrentRating = 0.0;
            ratingControl.ReloadData();
        }
    }

    #endregion
}
