using System;
using System.Data;
using System.Web.UI;
using System.Web.UI.WebControls;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.UIControls;
using CMS.SettingsProvider;

public partial class SiteManager_Administration_Users_User_Edit_General : AdministrationPage
{
    #region "Protected variables"

    protected int userId = 0;
    protected string password;
    protected string myCulture = string.Empty;
    protected string myUICulture = string.Empty;

    #endregion


    #region "Page events"

    protected void Page_Load(object sender, EventArgs e)
    {
        // Check "read" permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Users", "Read"))
        {
            RedirectToAccessDenied("CMS.Users", "Read");
        }

        rfvFullName.ErrorMessage = ResHelper.GetString("Administration-User_New.RequiresFullName");
        rfvUserName.ErrorMessage = ResHelper.GetString("Administration-User_New.RequiresUserName");

        Page.ClientScript.RegisterClientScriptBlock(typeof(string), "PictDelConfirm", ScriptHelper.GetScript("" +
            "function DeleteConfirmation(){ return confirm(" + ScriptHelper.GetString(ResHelper.GetString("MyProfile.PictDeleteConfirm")) + ");}"));

        CheckBoxLabelIsGlobalAdministrator.Enabled = CMSContext.CurrentUser.IsGlobalAdministrator;
        userId = QueryHelper.GetInteger("userid", 0);

        if (userId != 0)
        {
            // Check that only global administrator can edit global administrator's accouns
            UserInfo ui = UserInfoProvider.GetUserInfo(userId);
            if (!CMSContext.CurrentUser.IsGlobalAdministrator && ui != null && ui.UserIsGlobalAdministrator)
            {
                plcTable.Visible = false;
                lblError.Text = ResHelper.GetString("Administration-User_List.ErrorGlobalAdmin");
                lblError.Visible = true;
            }

            if (!RequestHelper.IsPostBack())
            {
                LoadData();
            }
        }
    }


    /// <summary>
    /// Saves data of edited user from TextBoxes into DB.
    /// </summary>
    protected void btnOk_Click(object sender, EventArgs e)
    {
        // Check "modify" permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Users", "Modify"))
        {
            RedirectToAccessDenied("CMS.Users", "Modify");
        }

        string result = ValidateGlobalAndDeskAdmin(userId);

        if (result == String.Empty)
        {
            // Finds whether required fields are not empty
            result = new Validator().NotEmpty(txtUserName.Text, ResHelper.GetString("Administration-User_New.RequiresUserName")).IsUserName(txtUserName.Text, ResHelper.GetString("Administration-User_New.NotValidUserName")).NotEmpty(txtFullName.Text, ResHelper.GetString("Administration-User_New.RequiresFullName")).Result;
        }

        if (result == String.Empty)
        {
            UserInfo ui = UserInfoProvider.GetUserInfo(userId);
            password = ui.GetValue("UserPassword").ToString();
            userId = ui.UserID;

            UserInfo uiTest = UserInfoProvider.GetUserInfo(txtUserName.Text);
            if ((uiTest == null) || (uiTest.UserID == userId))
            {
                if (ui == null)
                {
                    ui = new UserInfo();
                }

                bool globAdmin = ui.IsGlobalAdministrator;
                bool editor = ui.IsEditor;

                // Email format validation
                string email = txtEmail.Text.Trim();
                if (((email != string.Empty) && (!ValidationHelper.IsEmail(email))))
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("Administration-User_New.WrongEmailFormat");
                    return;
                }

                bool oldGlobal = ui.IsGlobalAdministrator;
                bool oldEditor = ui.IsEditor;

                ui.Email = email;
                ui.FirstName = txtFirstName.Text.Trim();
                ui.FullName = txtFullName.Text.Trim();
                ui.LastName = txtLastName.Text.Trim();
                ui.MiddleName = txtMiddleName.Text.Trim();
                ui.UserName = txtUserName.Text.Trim();
                ui.Enabled = CheckBoxEnabled.Checked;
                ui.IsEditor = CheckBoxIsEditor.Checked;
                ui.UserIsHidden = chkIsHidden.Checked;
                ui.IsGlobalAdministrator = CMSContext.CurrentUser.IsGlobalAdministrator && CheckBoxLabelIsGlobalAdministrator.Checked;
                ui.IsExternal = chkIsExternal.Checked;
                ui.UserIsDomain = chkIsDomain.Checked;
                ui.SetValue("UserPassword", password);
                ui.UserID = userId;
                ui.UserStartingAliasPath = txtUserStartingPath.Text.Trim();

                LoadUserLogon(ui);

                // Set values of cultures.
                if (lstCulture.SelectedValue == "0")
                {
                    ui.PreferredCultureCode = "";
                }
                else
                {
                    CultureInfo ci = CultureInfoProvider.GetCultureInfo(Convert.ToInt32(lstCulture.SelectedValue));
                    ui.PreferredCultureCode = ci.CultureCode;
                }

                if (lstUICulture.SelectedValue == "0")
                    ui.PreferredUICultureCode = "";
                else
                {
                    UICultureInfo ciUI = UICultureInfoProvider.GetUICultureInfo(Convert.ToInt32(lstUICulture.SelectedValue));
                    ui.PreferredUICultureCode = ciUI.UICultureCode;
                }

                // Define domain variable
                string domains = null;

                // Get all user sites
                DataTable ds = UserInfoProvider.GetUserSites(ui.UserID);
                if (!DataHelper.DataSourceIsEmpty(ds))
                {
                    foreach (DataRow dr in ds.Rows)
                    {
                        domains += ValidationHelper.GetString(dr["SiteDomainName"], string.Empty) + ";";
                    }

                    // Remove  ";" at the end
                    if (domains != null)
                    {
                        domains = domains.Remove(domains.Length - 1);
                    }
                }
                else
                {
                    DataSet siteDs = SiteInfoProvider.GetAllSites();
                    if (!DataHelper.DataSourceIsEmpty(siteDs))
                    {
                        foreach (DataRow dr in siteDs.Tables[0].Rows)
                        {
                            domains += ValidationHelper.GetString(dr["SiteDomainName"], string.Empty) + ";";
                        }

                        // Remove  ";" at the end
                        if (domains != null)
                        {
                            domains = domains.Remove(domains.Length - 1);
                        }
                    }
                }

                // Check limitations for Global administrator
                if (ui.IsGlobalAdministrator && !oldGlobal)
                {
                    if (!UserInfoProvider.LicenseVersionCheck(domains, FeatureEnum.GlobalAdmininistrators, VersionActionEnum.Insert, globAdmin))
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("License.MaxItemsReachedGlobal");
                    }
                }

                // Check limitations for editors
                if (ui.IsEditor && !oldEditor)
                {
                    if (!UserInfoProvider.LicenseVersionCheck(domains, FeatureEnum.Editors, VersionActionEnum.Insert, editor))
                    {
                        lblError.Visible = true;
                        lblError.Text = ResHelper.GetString("License.MaxItemsReachedEditor");
                    }
                }

                // Check whether email is unique if it is required
                if (!UserInfoProvider.IsEmailUnique(email, ui))
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("UserInfo.EmailAlreadyExist");
                    return;
                }

                if (!lblError.Visible)
                {
                    UserInfoProvider.SetUserInfo(ui);

                    lblInfo.Visible = true;
                    lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                }
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("Administration-User_New.UserExists");
            }
        }
        else
        {
            lblError.Visible = true;
            lblError.Text = result;
        }
    }

    #endregion


    #region "Protected methods"

    /// <summary>
    /// Loads data of edited user from DB into TextBoxes.
    /// </summary>
    protected void LoadData()
    {
        // Fill lstCulture
        lstCulture.DataSource = CultureInfoProvider.GetAllCultures();
        lstCulture.DataTextField = "CultureName";
        lstCulture.DataValueField = "CultureID";
        lstCulture.DataBind();

        lstCulture.Items.Insert(0, ResHelper.GetString("Administration-User_Edit.Default"));
        lstCulture.Items[0].Value = "0";

        // Fill lstUICulture

        lstUICulture.DataSource = UICultureInfoProvider.GetAllUICultures();
        lstUICulture.DataTextField = "UICultureName";
        lstUICulture.DataValueField = "UICultureID";
        lstUICulture.DataBind();

        lstUICulture.Items.Insert(0, ResHelper.GetString("Administration-User_Edit.Default"));
        lstUICulture.Items[0].Value = "0";

        UserInfo ui = UserInfoProvider.GetUserInfo(userId);

        if (ui != null)
        {
            txtEmail.Text = ui.Email;
            txtFirstName.Text = ui.FirstName;
            txtFullName.Text = ui.FullName;
            txtLastName.Text = ui.LastName;
            txtMiddleName.Text = ui.MiddleName;
            txtUserName.Text = ui.UserName;

            CheckBoxEnabled.Checked = ui.Enabled;
            CheckBoxIsEditor.Checked = ui.IsEditor;
            CheckBoxLabelIsGlobalAdministrator.Checked = ui.IsGlobalAdministrator;
            chkIsExternal.Checked = ui.IsExternal;
            chkIsDomain.Checked = ui.UserIsDomain;
            chkIsHidden.Checked = ui.UserIsHidden;
            password = ui.GetValue("UserPassword").ToString();

            if (ui.IsPublic())
            {
                txtUserName.Enabled = false;
            }

            myCulture = ui.PreferredCultureCode;
            myUICulture = ui.PreferredUICultureCode;

            txtUserStartingPath.Text = ui.UserStartingAliasPath;
        }

        // Select cultures for actual user or set default
        if (!string.IsNullOrEmpty(myCulture))
        {
            CultureInfo ci = CultureInfoProvider.GetCultureInfo(myCulture);
            if (ci == null)
            {
                lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue("0"));
            }
            else
            {
                lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue(ci.CultureID.ToString()));
            }
        }
        else
        {
            lstCulture.SelectedIndex = lstCulture.Items.IndexOf(lstCulture.Items.FindByValue("0"));
        }

        if (!string.IsNullOrEmpty(myUICulture))
        {
            try
            {
                UICultureInfo ciUI = UICultureInfoProvider.GetUICultureInfo(myUICulture);
                lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue(ciUI.UICultureID.ToString()));
            }
            catch
            {
                lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue("0"));
            }
        }
        else
        {
            lstUICulture.SelectedIndex = lstUICulture.Items.IndexOf(lstUICulture.Items.FindByValue("0"));
        }

        if (ui != null)
        {
            lblCreatedInfo.Text = ui.UserCreated.ToString();
            lblLastLogonInfo.Text = ui.LastLogon.ToString();

            LoadUserLogon(ui);

            if (ui.UserCreated == DataHelper.DATETIME_NOT_SELECTED)
            {
                lblCreatedInfo.Text = ResHelper.GetString("general.na");
            }

            if (ui.LastLogon == DataHelper.DATETIME_NOT_SELECTED)
            {
                lblLastLogonInfo.Text = ResHelper.GetString("general.na");
            }
        }
    }


    /// <summary>
    /// Displays user's last logon information
    /// </summary>
    /// <param name="ui">User info</param>
    protected void LoadUserLogon(UserInfo ui)
    {
        if ((ui.UserLastLogonInfo != null) && (ui.UserLastLogonInfo.ColumnNames != null))
        {
            plcUserLastLogonInfo.Controls.Add(new LiteralControl("<br />"));
            foreach (string column in ui.UserLastLogonInfo.ColumnNames)
            {
                Label lbl = new Label();
                lbl.Text = HTMLHelper.HTMLEncode(TextHelper.LimitLength(ui.UserLastLogonInfo[column], 80, "...")) + "<br />";
                lbl.ToolTip = HTMLHelper.HTMLEncode(column + " - " + ui.UserLastLogonInfo[column]);
                plcUserLastLogonInfo.Controls.Add(lbl);
            }

            plcUserLastLogonInfo.Controls.Add(new LiteralControl("<br />"));
        }
        else
        {
            plcUserLastLogonInfo.Controls.Add(new LiteralControl(ResHelper.GetString("general.na") + "<br />"));
        }
    }


    /// <summary>
    /// Check whether current user is allowed to modify another user. Return "" or error message.
    /// </summary>
    /// <param name="userId">Modified user</param>
    protected string ValidateGlobalAndDeskAdmin(int userId)
    {
        string result = String.Empty;

        if (CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            return result;
        }

        UserInfo userInfo = UserInfoProvider.GetUserInfo(userId);
        if (userInfo == null)
        {
            result = ResHelper.GetString("Administration-User.WrongUserId");
        }
        else if (userInfo.IsGlobalAdministrator)
        {
            result = ResHelper.GetString("Administration-User.NotAllowedToModify");
        }
        return result;
    }

    #endregion
}
