using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.WorkflowEngine;
using CMS.CMSHelper;
using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.UIControls;

public partial class SiteManager_Development_Workflows_Workflow_Step_Roles : SiteManagerPage
{
    #region "Protected variables"

    protected int workflowStepId = 0;

    #endregion


    #region "Page events"

    protected void Page_Load(object sender, EventArgs e)
    {
        lblSite.Text = ResHelper.GetString("Administration-User_Edit_Sites.SelectSite");
        btnOK.Text = ResHelper.GetString("General.OK");

        workflowStepId = QueryHelper.GetInteger("workflowStepId", 0);

        if (!RequestHelper.IsPostBack())
        {
            DataSet sitesSet = SiteInfoProvider.GetSites(null, "SiteDisplayName", "SiteDisplayName,SiteID");
            DataTable sitesTable = sitesSet.Tables[0];
            sitesTable.DefaultView.Sort = "SiteDisplayName";

            drpSites.DataSource = sitesTable;
            drpSites.DataTextField = "SiteDisplayName";
            drpSites.DataValueField = "SiteID";
            drpSites.DataBind();

            if (drpSites.Items.Count > 0)
            {
                drpSites.SelectedValue = CMSContext.CurrentSiteID.ToString();
                GridViewInitialization();
            }
        }
    }

    #endregion


    #region "Control handling"

    protected void drpSites_SelectedIndexChanged(object sender, EventArgs e)
    {
        if (drpSites.SelectedIndex > -1)
        {
            GridViewInitialization();
        }
    }


    protected void GridViewRoles_DataBound(object sender, EventArgs e)
    {
        if (GridViewRoles.Rows.Count != 0)
        {
            btnOK.Visible = true;
            CheckBox chkIsAuthorized;
            DataSet stepsRolesSet;
            DataTable stepsRoleTable = null;
            for (int i = 0; i < GridViewRoles.Rows.Count; i++)
            {
                chkIsAuthorized = (CheckBox)GridViewRoles.Rows[i].FindControl("chkSelect");
                chkIsAuthorized.Checked = false;
                stepsRolesSet = WorkflowStepInfoProvider.GetStepRoles(workflowStepId);
                if (stepsRolesSet != null)
                {
                    stepsRoleTable = stepsRolesSet.Tables[0];
                }
                if ((stepsRoleTable != null) && (stepsRoleTable.Rows.Count > 0))
                {
                    for (int j = 0; j < stepsRoleTable.Rows.Count; j++)
                    {
                        if (stepsRoleTable.Rows[j]["RoleID"].ToString() == GridViewRoles.Rows[i].Cells[2].Text)
                        {
                            chkIsAuthorized.Checked = true;
                            break;
                        }
                    }
                }
            }
        }
        else
        {
            btnOK.Visible = false;
            lblError.Visible = true;
            lblError.Text = ResHelper.GetString("Administration-User_Edit_Roles.SiteWithNoRoles");
        }
    }


    protected void btnOK_Click(object sender, EventArgs e)
    {
        for (int i = 0; i < GridViewRoles.Rows.Count; i++)
        {
            bool isChecked = ((CheckBox)GridViewRoles.Rows[i].FindControl("chkSelect")).Checked;

            string roleId = GridViewRoles.Rows[i].Cells[2].Text;

            if (isChecked)
            {
                // If role is not authorized, authorize it
                if (!IsRoleAuthorized(roleId, workflowStepId))
                {
                    WorkflowStepRoleInfoProvider.AddRoleToWorkflowStep(workflowStepId, Convert.ToInt32(roleId));
                }
            }
            else
            {
                // If role is authorized, unauthorize it
                if (IsRoleAuthorized(roleId, workflowStepId))
                {
                    WorkflowStepRoleInfoProvider.RemoveRoleFromWorkflowStep(workflowStepId, Convert.ToInt32(roleId));
                }
            }
        }

        lblInfo.Visible = true;
        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
    }

    #endregion


    #region "Protected methods"

    protected void GridViewInitialization()
    {
        int currentSiteId = Convert.ToInt32(drpSites.SelectedItem.Value);
        DataSet dsRoles = RoleInfoProvider.GetAllRoles(currentSiteId, false, false);
        bool rolesExist = !DataHelper.DataSourceIsEmpty(dsRoles);
        if (rolesExist)
        {
            DataTable dt = dsRoles.Tables[0];
            dt.DefaultView.Sort = "RoleDisplayName";
            GridViewRoles.Columns[2].Visible = true;
            GridViewRoles.Columns[1].HeaderText = ResHelper.GetString("WorkflowStep.RoleName");
            GridViewRoles.DataSource = dt;
            GridViewRoles.DataBind();
            GridViewRoles.Columns[2].Visible = false;
        }
        GridViewRoles.Visible = rolesExist;
    }


    protected bool IsRoleAuthorized(string roleId, int workflowStepId)
    {
        DataSet stepsRolesSet;
        DataTable stepsRoleTable = null;

        stepsRolesSet = WorkflowStepInfoProvider.GetStepRoles(workflowStepId);
        if (stepsRolesSet != null)
        {
            stepsRoleTable = stepsRolesSet.Tables[0];
        }
        if ((stepsRoleTable != null) && (stepsRoleTable.Rows.Count > 0))
        {
            for (int j = 0; j < stepsRoleTable.Rows.Count; j++)
            {
                if (stepsRoleTable.Rows[j]["RoleID"].ToString() == roleId)
                {
                    return true;
                }
            }
        }
        return false;
    }

    #endregion
}
